@@ -20,8 +20,8 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110, USA.
  */
 
 #include "ldtp.h"
@@ -41,95 +41,18 @@ extern gboolean ldtp_debug;
 extern gint ldtp_gui_timeout;
 extern gint ldtp_obj_timeout;
 extern GHashTable *event_notifier;
+extern GHashTable *client_context;
 
-static GHashTable *recording_handler = NULL;
 extern pthread_mutex_t cb_mutex;
 
 static gboolean
-search_recording_handler (gpointer key, gpointer value, gpointer user_data)
+is_cctxt_registered_callback (gpointer key, gpointer value, gpointer user_data)
 {
-	if (!key && !user_data)
-		return FALSE;
-	if (g_utf8_collate (key, user_data) == 0)
-		return TRUE;
-	if (g_pattern_match_simple (key, user_data))
+	if (value && user_data && value == user_data)
 		return TRUE;
 	return FALSE;
 }
 
-static gboolean
-remove_recording_handler (gpointer key, gpointer value, gpointer user_data)
-{
-	if (!key && !user_data)
-		return FALSE;
-	if (g_utf8_collate (key, user_data) == 0) {
-		g_free (key);
-		return TRUE;
-	}
-	if (g_pattern_match_simple (key, user_data)) {
-		g_free (key);
-		return TRUE;
-	}
-	return FALSE;
-}
-
-static void
-register_recording_handler (LDTPClientContext* cctxt, LDTPErrorCode* err)
-{
-	LDTPClientContext *tmp = NULL;
-	if (!cctxt || !cctxt->rec || !cctxt->req)
-		*err = LDTP_ERROR_ARGUMENT_NULL;
-
-	if (!recording_handler)
-		recording_handler = g_hash_table_new (&g_str_hash, &g_str_equal);
-
-	if (!cctxt->req->context) {
-		tmp = g_hash_table_find (recording_handler, search_recording_handler, "all");
-		if (tmp) {
-			*err = LDTP_ERROR_RECORDER_ALREADY_REGISTERED;
-			return;
-		}
-		g_hash_table_insert (recording_handler, g_strdup ("all"), cctxt);
-	}
-	else {
-		tmp = g_hash_table_find (recording_handler, search_recording_handler, cctxt->req->context);
-		if (tmp) {
-			*err = LDTP_ERROR_RECORDER_ALREADY_REGISTERED;
-			return;
-		}
-		g_hash_table_insert (recording_handler, g_strdup ((gchar *)cctxt->req->context), cctxt);
-	}
-	*err = LDTP_ERROR_SUCCESS;
-}
-
-static void
-unregister_recording_handler (LDTPClientContext* cctxt)
-{
-	LDTPClientContext *tmp = NULL;
-	if (!cctxt || !cctxt->rec || !cctxt->req) {
-		g_print ("Argument NULL\n");
-		return;
-	}
-
-	if (!recording_handler) {
-		g_print ("Record handler not registered\n");
-		return;
-	}
-
-	if (!cctxt->req->context) {
-		tmp = g_hash_table_find (recording_handler, search_recording_handler, "all");
-		if (tmp) {
-			g_hash_table_foreach_remove (recording_handler, remove_recording_handler, "all");
-		}
-	}
-	else {
-		tmp = g_hash_table_find (recording_handler, search_recording_handler, cctxt->req->context);
-		if (tmp) {
-			g_hash_table_foreach_remove (recording_handler, remove_recording_handler, cctxt->req->context);
-		}
-	}
-}
-
 static void
 register_window_creation_event (LDTPClientContext* cctxt, LDTPErrorCode* err)
 {
@@ -217,7 +140,7 @@ generate_response_packet (LDTPClientContext* cctxt, LDTPErrorCode* err, char **r
 			DATA_END_ELEMENT_LEN +
 			cctxt->resp->data_len;
 		memset (buf1, 0x00, 16);
-		sprintf (buf1, "%d", cctxt->resp->data_len);
+		sprintf (buf1, "%o", cctxt->resp->data_len);
 		resp_len += strlen (buf1);
 	}
 
@@ -252,82 +175,6 @@ generate_response_packet (LDTPClientContext* cctxt, LDTPErrorCode* err, char **r
 	*resp_pckt = resp_xml;
 }
 
-void
-generate_record_response_packet (LDTPClientContext* cctxt,
-				 LDTPErrorCode* err,
-				 char **resp_pckt,
-				 uint32_t *resp_size)
-{
-	uint32_t resp_len = 0;
-	char buf [16];  
-	char buf1 [16];  
-	char *resp_xml = NULL;
-	char *data_pckt = NULL;
-
-	if (!cctxt || !cctxt->resp) {
-		*err = LDTP_ERROR_ARGUMENT_NULL;
-		return;
-	}
-
-	resp_len = XML_HEADER_LEN + 
-		RESPONSE_ELEMENT_LEN + 
-		RESPONSE_END_ELEMENT_LEN;
-	/* Varadhan
-	   FIXME: Localization?? 
-	*/
-	if (cctxt->req->request_id)
-		resp_len += g_utf8_strlen ((gchar *)cctxt->req->request_id, -1);
-	if (cctxt->resp->resp_status)
-		resp_len += g_utf8_strlen (ldtp_error_get_message (cctxt->resp->resp_status), -1);
-
-	memset (buf, 0x00, 16);
-	sprintf (buf, "%d", cctxt->resp->resp_status);
-	resp_len += strlen (buf);
-
-	if (cctxt->resp->data && cctxt->resp->data_len > 0) {
-		resp_len += RESPONSE_ID_ELEMENT_LEN + 
-			RESPONSE_ID_END_ELEMENT_LEN +
-			DATA_ELEMENT_LEN +
-			ATTRIBUTE_LENGTH_ELEMENT_LEN +
-			ATTRIBUTE_LENGTH_END_ELEMENT_LEN +
-			RECORD_FILE_ELEMENT_LEN +
-			RECORD_FILE_END_ELEMENT_LEN +
-			DATA_END_ELEMENT_LEN +
-			cctxt->resp->data_len;
-		memset (buf1, 0x00, 16);
-		sprintf (buf1, "%d", cctxt->resp->data_len);
-		resp_len += strlen (buf1);
-	}
-
-	if (cctxt->resp->data && cctxt->resp->data_len > 0) 
-		data_pckt = g_strconcat (DATA_ELEMENT,
-					 ATTRIBUTE_LENGTH_ELEMENT,
-					 buf1, ATTRIBUTE_LENGTH_END_ELEMENT,
-					 RECORD_FILE_ELEMENT, 
-					 cctxt->resp->data,
-					 RECORD_FILE_END_ELEMENT, 
-					 DATA_END_ELEMENT, NULL);
-
-	resp_xml = g_strdup_printf ("%s%s%s%s%s%s%s%s%s%s%s%s%s%s%s",
-				    XML_HEADER,
-				    RESPONSE_ELEMENT,
-				    RESPONSE_ID_ELEMENT,
-				    cctxt->req->request_id,
-				    RESPONSE_ID_END_ELEMENT,
-				    STATUS_ELEMENT, ATTRIBUTE_CODE_ELEMENT,
-				    buf, ATTRIBUTE_CODE_END_ELEMENT,
-				    ATTRIBUTE_MSG_ELEMENT, 
-				    ldtp_error_get_message (cctxt->resp->resp_status),
-				    ATTRIBUTE_MSG_END_ELEMENT,
-				    STATUS_END_ELEMENT,
-				    data_pckt != NULL ? data_pckt : "",
-				    RESPONSE_END_ELEMENT);
-
-	*err = LDTP_ERROR_SUCCESS;
-	*resp_size = strlen (resp_xml);
-	*resp_pckt = resp_xml;
-}
-
 void
 generate_notification_packet (LDTPClientContext* cctxt, LDTPErrorCode* err, char **resp_pckt, uint32_t *resp_size)
 {
@@ -373,7 +220,7 @@ generate_notification_packet (LDTPClientContext* cctxt, LDTPErrorCode* err, char
 			DATA_END_ELEMENT_LEN +
 			cctxt->resp->data_len;
 		memset (buf1, 0x00, 16);
-		sprintf (buf1, "%d", cctxt->resp->data_len);
+		sprintf (buf1, "%o", cctxt->resp->data_len);
 		resp_len += strlen (buf1);
 	}
 
@@ -902,7 +749,7 @@ handle_request (LDTPClientContext* cctxt,
 	}
 
 	case LDTP_CMD_GENERATEKEYEVENT:
-		*err = generate_keyboard_sequence (cctxt->req->context, cctxt->log_fp);
+		*err = device_main (cctxt, cctxt->req->command);
 		return;
 
 	case LDTP_CMD_SETCONTEXT:
@@ -1328,34 +1175,6 @@ handle_request (LDTPClientContext* cctxt,
 		cctxt->resp->data_len = g_utf8_strlen (obj_property, -1);
 		return;
 	}
-	
-	case LDTP_CMD_STARTRECORD: {
-		g_print ("Entered LDTP_CMD_STARTRECORD\n");
-		register_recording_handler (cctxt, err);
-		if (*err != LDTP_ERROR_SUCCESS)
-			return;
-		*err = record_main (cctxt, cctxt->req->command);
-		return;
-	}
-	case LDTP_CMD_STOPRECORD: {
-		LDTPClientContext *tmp = NULL;
-
-		g_print ("Entered LDTP_CMD_STOPRECORD\n");
-		if (!cctxt->req->context) {
-			tmp = g_hash_table_find (recording_handler, search_recording_handler, "all");
-		}
-		else {
-			tmp = g_hash_table_find (recording_handler, search_recording_handler, cctxt->req->context);
-		}
-		if (!tmp) {
-			*err = LDTP_ERROR_WRONG_COMMAND_SEQUENCE;
-			return;
-		}
-		tmp->sock_fd = cctxt->sock_fd;
-		*err = record_main (tmp, cctxt->req->command);
-		unregister_recording_handler (cctxt);
-		return;
-	}
 	}
 
 	/* 
@@ -1425,7 +1244,12 @@ handle_request (LDTPClientContext* cctxt,
 		break;
 
 	case SPI_ROLE_TEXT:
+#ifdef ENABLE_NEWROLES
+	case SPI_ROLE_ENTRY:
+#endif
 	case SPI_ROLE_EDITBAR:
+	case SPI_ROLE_PARAGRAPH:
+	case SPI_ROLE_AUTOCOMPLETE:
 	case SPI_ROLE_PASSWORD_TEXT:
 		*err = text_main (cctxt, cctxt->req->command);
 		break;
@@ -1475,6 +1299,7 @@ handle_request (LDTPClientContext* cctxt,
 		*err = table_main (cctxt, cctxt->req->command);
 		break;
 
+	case SPI_ROLE_TREE:
 	case SPI_ROLE_TREE_TABLE:
 		*err = tree_table_main (cctxt, cctxt->req->command);
 		break;
@@ -1524,7 +1349,7 @@ handle_request (LDTPClientContext* cctxt,
 	ldtp_gui_free_gui_handle (cctxt->gui_handle);
 }
 
-void 
+void *
 handle_client (void *ptr)
 {
 	int* sock_fd = (int *)ptr;
@@ -1534,7 +1359,7 @@ handle_client (void *ptr)
 	uint32_t packet_read;
 	uint32_t pckt_len = 0;
 	uint32_t i = 0;
-	uint32_t bytes_read = 0;
+	size_t bytes_read  = 0;
 	uint32_t resp_size = 0;
 	char *resp_pckt = NULL;
 
@@ -1546,7 +1371,6 @@ handle_client (void *ptr)
 	cctxt = g_new0 (LDTPClientContext, 1);
 	cctxt->app_map = NULL;
 	cctxt->app_handle = NULL;
-	cctxt->rec = g_new0 (LDTPRecord, 1);
 	cctxt->req = g_new0 (LDTPRequest, 1);
 	ldtp_request_init (cctxt->req);
 	cctxt->resp = g_new0 (LDTPResponse, 1);
@@ -1625,10 +1449,6 @@ handle_client (void *ptr)
 			g_free (pckt);
 		pckt = NULL;
 
-		if (status == LDTP_ERROR_STOP_RECORD_THREAD) {
-			break;
-		}
-
 		cctxt->resp->resp_status = status;
 		generate_response_packet (cctxt, &status, &resp_pckt, &resp_size);
 		if (status != LDTP_ERROR_SUCCESS) {
@@ -1651,12 +1471,6 @@ handle_client (void *ptr)
 		}
 		cctxt->resp->data_len = 0;
 	}
-	if (cctxt->window_name) {
-		g_free (cctxt->window_name);
-		cctxt->window_name = NULL;
-	}
-	pthread_exit ((void *)0);
-
  error:
 	g_print ("handle_client: error:\n");
 	cctxt->resp->resp_status = status;
@@ -1703,6 +1517,11 @@ handle_client (void *ptr)
 		cctxt->app_handle = NULL;
 	}
 
+	if (client_context) {
+		guint count = g_hash_table_foreach_remove (client_context, is_cctxt_registered_callback, cctxt);
+		g_print ("Removed %d entries from client context hash table\n", count);
+	}
+
 	ldtp_appmap_free (cctxt->app_map);
 	if (cctxt && cctxt->resp)
 		status = cctxt->resp->resp_status;
@@ -1711,8 +1530,6 @@ handle_client (void *ptr)
 
 	g_free (cctxt->req);
 	cctxt->req = NULL;
-	g_free (cctxt->rec);
-	cctxt->rec = NULL;
 	g_free (cctxt->resp);
 	cctxt->resp = NULL;
 	g_free (cctxt->locale_lang);
