@@ -19,8 +19,8 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110, USA.
  */
 
 #ifndef _CLIENT_HANDLER_H
@@ -32,7 +32,6 @@
 #include "ldtp-gui.h"
 #include "ldtp-request.h"
 #include "ldtp-response.h"
-#include "ldtp-record.h"
 #include "ldtp-error.h"
 
 typedef struct _LDTPClientContext LDTPClientContext;
@@ -52,8 +51,6 @@ struct _LDTPClientContext {
 	gboolean locale_set;          /* Locale flag set or not */
 	Accessible* app_handle;	      /* Handle to the application's main window - Accessibiliy handle */
 	GHashTable* app_map;	      /* Hashtable that maintains the Application Map read from appmap file */
-	GHashTable* obj_cache;	      /* Hashtable that maintains the cache of gui-objects. */
-	LDTPRecord *rec;              /* Recording info */
 	LDTPRequest* req;	      /* decoded-request-packet from client */
 	LDTPResponse* resp;           /* response-structure that will be send to client */
 	LDTPGuiHandle* gui_handle;    /* Handle to the gui-object on which the action is sought */
@@ -65,12 +62,10 @@ struct _Packet {
 	uint32_t len;
 };
 
-void handle_client (void *ptr);
+void *handle_client (void *ptr);
 
 void generate_response_packet (LDTPClientContext* cctxt, LDTPErrorCode* err,
 			       char **resp_packet, uint32_t *resp_size);
-void generate_record_response_packet (LDTPClientContext* cctxt, LDTPErrorCode* err,
-				      char **resp_packet, uint32_t *resp_size);
 void generate_notification_packet (LDTPClientContext* cctxt, LDTPErrorCode* err,
 			       char **resp_packet, uint32_t *resp_size);
 void send_response (int sockfd, char *resp_xml, uint32_t resp_len, LDTPErrorCode* err);
