@@ -21,8 +21,8 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110, USA.
  */
 
 #include "ldtp.h"
@@ -30,7 +30,6 @@
 #include "ldtp-error.h"
 #include "ldtp-utils.h"
 #include "ldtp-logger.h"
-#include "ldtp-gui-cb.h"
 #include "ldtp-command.h"
 #include "ldtp-gui-comp.h"
 
@@ -221,12 +220,12 @@ select_item (LDTPClientContext* cctxt)
 			error = text_main (cctxt, LDTP_CMD_VERIFYSETTEXT);
 			Accessible_unref (text);
 			cctxt->gui_handle->handle = object;
-			if (error != LDTP_ERROR_SUCCESS) {
-				g_print ("Combo box select verify action failed\n");
-				log_msg (LDTP_LOG_CAUSE, "Combo box select verify action failed", cctxt->log_fp);
-				return  (LDTP_ERROR_VERIFY_SETTEXTVALUE_FAILED);
-			}
+			if (error == LDTP_ERROR_SUCCESS)
+				return  (LDTP_ERROR_SUCCESS);
 		}
+		g_print ("Combo box select verify action failed\n");
+		log_msg (LDTP_LOG_CAUSE, "Combo box select verify action failed", cctxt->log_fp);
+		return  (LDTP_ERROR_VERIFY_SETTEXTVALUE_FAILED);
 	} else if (type == SPI_ROLE_MENU) {
 		menu_object = get_menu_handle (object);
 		if (menu_object == NULL) {
@@ -576,37 +575,16 @@ verify_set_text_value (LDTPClientContext* cctxt)
 			log_msg (LDTP_LOG_CAUSE, "Verify Combo box SetTextValue child object is NULL", cctxt->log_fp);
 			return  (LDTP_ERROR_VERIFY_SETTEXTVALUE_FAILED);
 		}
-	}
-	if (child_type == SPI_ROLE_MENU) {
+	} else if (child_type == SPI_ROLE_MENU) {
 		gboolean flag = FALSE;
-		Accessible *menu = Accessible_getChildAtIndex (object, 0);
-		if (menu) {
-			long i;
-			Accessible *child;
-			AccessibleStateSet *state;
-			for (i = 0; i < Accessible_getChildCount (menu); i++) {
-				child = Accessible_getChildAtIndex (menu, i);
-				if (!child)
-					continue;
-				state = Accessible_getStateSet (child);
-				if (state) {
-					if (AccessibleStateSet_contains (state, SPI_STATE_CHECKED) ||
-					    AccessibleStateSet_contains (state, SPI_STATE_SELECTED)) {
-						char *name = Accessible_getName (child);
-						if (name && cctxt && cctxt->req && cctxt->req->arg_list &&
-						    cctxt->req->arg_list->data && (g_utf8_collate (cctxt->req->arg_list->data, name) == 0)) {
-							g_print ("Name: %s - %s\n", name, (char *)cctxt->req->arg_list->data);
-							flag = TRUE;
-						}
-						SPI_freeString (name);
-					}
-					AccessibleStateSet_unref (state);
-				}
-				Accessible_unref (child);
-				if (flag)
-					break;
+		char *name = Accessible_getName (object);
+		if (name) {
+			if (cctxt && cctxt->req && cctxt->req->arg_list &&
+			    cctxt->req->arg_list->data && (g_utf8_collate (cctxt->req->arg_list->data, name) == 0)) {
+				g_print ("Name: %s - %s\n", name, (char *)cctxt->req->arg_list->data);
+				flag = TRUE;
 			}
-			Accessible_unref (menu);
+			SPI_freeString (name);
 		}
 		if (flag)
 			return  (LDTP_ERROR_SUCCESS);
@@ -627,8 +605,8 @@ verify_select_item (LDTPClientContext* cctxt)
 	error = verify_set_text_value (cctxt);
 
 	if (error != LDTP_ERROR_SUCCESS) {
-		g_print ("verify Combo box select action failed\n");
-		log_msg (LDTP_LOG_CAUSE, "verify Combo box select action failed", cctxt->log_fp);
+		g_print ("verify combo box select action failed\n");
+		log_msg (LDTP_LOG_CAUSE, "verify combo box select action failed", cctxt->log_fp);
 		return  (LDTP_ERROR_VERIFY_ITEM_FAILED);
 	}
 	return  (LDTP_ERROR_SUCCESS);
@@ -761,32 +739,6 @@ get_text_value (LDTPClientContext* cctxt)
 	}
 }
 
-/*
-  combo_box_cb function is used in ldtp-record.c to record the combo-box with list inside them
-*/
-void
-combo_box_cb (FILE *fp, 
-	      const AccessibleEvent *event, 
-	      char *window_name, 
-	      char *window_type,
-	      char *combobox_role, 
-	      char *combobox_name)
-{
-	char *name = NULL;
-	name = Accessible_getName (event->source);
-	if (name && fp) {
-		fprintf (fp,
-			 "<COMMAND><ACTION>CLICK</ACTION><WINDOW>%s</WINDOW><OBJECTTYPE>%s</OBJECTTYPE><CONTEXT>%s</CONTEXT><COMPONENT>%s</COMPONENT><ARGUMENTS><ARGUMENT>%s</ARGUMENT></ARGUMENTS></COMMAND>\n", 
-			 window_type,
-			 combobox_role,
-			 window_name,
-			 combobox_name,
-			 name);
-		fflush (fp);
-	}
-	SPI_freeString (name);
-}
-
 LDTPErrorCode 
 combo_box_main (LDTPClientContext* cctxt, int command)
 {
