@@ -19,8 +19,8 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110, USA.
  */
 
 #ifndef _DEVICE_H
@@ -50,6 +50,4 @@ struct KeyValue {
 	gint value;
 };
 	
-LDTPErrorCode generate_keyboard_sequence (char *input_string, FILE *log_fp);
-
 #endif
