@@ -21,8 +21,8 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110, USA.
  */
 
 #include "ldtp.h"
@@ -283,7 +283,7 @@ search_key_glob_based (gpointer key, gpointer value, gpointer user_data)
 	  if type and key matches then return true
 	*/
 	obj = (OBJInfo *) user_data;
-	if (obj->key && key) {
+	if (ldtp_debug && obj->key && key) {
 		g_print ("glob- key: %d - %d - %d - %s %s %ld %ld\n",
 			 obj->obj_is_window,
 			 g_pattern_match_simple ("frm*", obj->key),
@@ -298,7 +298,7 @@ search_key_glob_based (gpointer key, gpointer value, gpointer user_data)
 			if (g_pattern_match_string (obj->pattern, key))
 				return TRUE;
 		}
-		tmp = g_strdup_printf ("frm%s", key);
+		tmp = g_strdup_printf ("frm%s", (gchar *)key);
 		if (tmp && g_pattern_match_simple (tmp, key)) {
 			g_free (tmp);
 			return TRUE;
@@ -371,6 +371,7 @@ search_label_based (gpointer key, gpointer value, gpointer user_data)
 		if (!obj->obj_is_window || flag)
 			if (g_utf8_collate (label, tmp_data) == 0)
 				return TRUE;
+		// Search for mnemonics, if available then remove just _
 		if (g_utf8_strchr (label, -1, '_') == NULL)
 			return FALSE;
 		tmp = escape_character (label, '_');
@@ -389,6 +390,7 @@ search_label_based (gpointer key, gpointer value, gpointer user_data)
 		if (!obj->obj_is_window || flag)
 			if (g_utf8_collate (label_by, tmp_data) == 0)
 				return TRUE;
+		// Search for mnemonics, if available then remove just _
 		if (g_utf8_strchr (label_by, -1, '_') == NULL)
 			return FALSE;
 		tmp = escape_character (label, '_');
@@ -446,16 +448,16 @@ search_label_glob_based (gpointer key, gpointer value, gpointer user_data)
 	return FALSE;
 }
 
+/*
 static gboolean 
 search_label_name (gpointer key, gpointer value, gpointer user_data)
 {
-	
 	char *child_index = NULL;
 	UnknLabelProperty *tmp_data = (UnknLabelProperty *) user_data;
 	if (!value && !tmp_data && !key) {
 		return FALSE;
 	}
-	if (	g_hash_table_lookup_extended (value, "child_index", NULL, (gpointer) &child_index)) {
+	if (g_hash_table_lookup_extended (value, "child_index", NULL, (gpointer) &child_index)) {
 		if ((char *)key && tmp_data->str_child_index && tmp_data->parent_name)
 			g_print ("Key - Child index - Parent: %s - %s - %s\n",
 				 (char *)key, tmp_data->str_child_index,
@@ -476,6 +478,7 @@ search_label_name (gpointer key, gpointer value, gpointer user_data)
  	}
 	return FALSE;
 }
+*/
 
 static gboolean
 search_obj_after_stripping_space (gpointer key, gpointer value, gpointer user_data)
@@ -658,50 +661,3 @@ search_title_based (gpointer key, gpointer value, gpointer user_data)
 		g_free (tmp_key);
 	return FALSE;
 }
-
-char*
-get_unknown_obj_label (GHashTable *ht, char *parent_name, int *child_index, int child_index_count, FILE *log_fp)
-{
-	int i;
-	gboolean flag = FALSE;
-	char *obj_name = NULL;
-	//char *tmp_child_index = NULL;
-	//char *tmp_parent_name = NULL;
-	char str_child_index[256];
-	GHashTable *ht_context = NULL;
-
-	if (!ht) {
-		LDTPErrorCode err =  (LDTP_ERROR_ARGUMENT_NULL);
-		g_print ("%s\n", ldtp_error_get_message (err));
-		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (err), log_fp);
-		return NULL;
-	}
-
-	UnknLabelProperty *unkn_label_prop = (UnknLabelProperty*) calloc (sizeof (UnknLabelProperty), 1);
-
-	for (i = child_index_count - 1; i > 0; i--) {
-		if (i == child_index_count - 1)
-			unkn_label_prop->parent_name = parent_name;
-		else
-			unkn_label_prop->parent_name = unkn_label_prop->obj_name;
-		g_print ("**DEBUG** Inside Loop for %d %s\n", i, unkn_label_prop->parent_name);
-		sprintf (str_child_index, "%d", child_index[i-1]);
-		unkn_label_prop->str_child_index = str_child_index;
-		g_print ("--DEBUG-- Current child index and parent name are %s %s\n",
-			 unkn_label_prop->parent_name, 
-			 unkn_label_prop->str_child_index);
-		ht_context = g_hash_table_find (ht, search_label_name, unkn_label_prop);
-		if (!ht_context) {
-			g_print ("HashTable Context NULL\n");
-			flag = FALSE;
-			//return;
-			break; //Changing the break to return
-		}
-		g_print ("=========HashTable Context NOT NULL=========\n");
-		flag = TRUE;
- 	}
-	if (flag)
-		obj_name = unkn_label_prop->obj_name;
-	g_free (unkn_label_prop);
-	return obj_name;
-}
