@@ -19,8 +19,8 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110, USA.
  */
 
 #include <unistd.h>
@@ -89,9 +89,6 @@ ldtp_error_get_message (LDTPErrorCode error)
 	case LDTP_ERROR_OPENING_LOG_FILE: /* FIXME: its better we show the filename with full path */
 		msg = "Unable to open log file";
 		break;
-	case LDTP_ERROR_OPENING_RECORD_FILE: /* FIXME: its better we show the filename with full path */
-		msg = "Unable to open record file";
-		break;
 	case LDTP_ERROR_APP_NOT_RUNNING:
 		msg = "Application not running";
 		break;
@@ -277,6 +274,9 @@ ldtp_error_get_message (LDTPErrorCode error)
 	case LDTP_ERROR_UNABLE_TO_LIST_MENU_ITEMS:
 		msg = "Unable to list menu items";
 		break;
+	case LDTP_ERROR_UNABLE_TO_SELECT_LIST_ITEM:
+		msg = "Unable to select list item";
+		break;
 	case LDTP_ERROR_PAGE_TAB_NAME_SELECTION_FAILED:
 		msg = "Page tab name selection failed";
 		break;
@@ -547,12 +547,6 @@ ldtp_error_get_message (LDTPErrorCode error)
 	case LDTP_ERROR_WRONG_COMMAND_SEQUENCE:
 		msg = "Wrong command sequence, stop called before start";
 		break;
-	case LDTP_ERROR_STOP_RECORD_THREAD:
-		msg = "Wrong command sequence, stop called before start";
-		break;
-	case LDTP_ERROR_RECORDER_ALREADY_REGISTERED:
-		msg = "Recorder event already registered to listen for all / specified application";
-		break;
 	case LDTP_ERROR_UNABLE_TO_LAUNCH_APP:
 		msg = "Unable to launch application";
 		break;
