@@ -21,8 +21,8 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110, USA.
  */
 
 #include "ldtp.h"
@@ -40,6 +40,9 @@ static char *last_new_context = NULL;
 static char *last_existing_context = NULL;
 static pthread_mutex_t mutex = PTHREAD_MUTEX_INITIALIZER;
 
+extern GHashTable *client_context;
+extern pthread_mutex_t cb_mutex;
+
 static struct {
 	int states_count;
 	int states[10];
@@ -212,7 +215,7 @@ init_stack ()
 
 static struct node*
 trace_path_to_parent (GHashTable *context, char *context_name,
-		      GHashTable *component, FILE *log_fp,
+		      GHashTable *component, char **class_type, FILE *log_fp,
 		      LDTPClientContext *cctxt, LDTPErrorCode *err)
 {
 	struct node *head;
@@ -231,6 +234,8 @@ trace_path_to_parent (GHashTable *context, char *context_name,
 			log_msg (LDTP_LOG_CAUSE, "Unable to get_property", log_fp);
 			return NULL;
 		}
+		if (*class_type == NULL)
+			*class_type = get_property (component, "class", log_fp);
 		push (head, atoi (prop));
 		parent_name = get_property (component, "parent", log_fp);
 		if (ldtp_debug && parent_name && context_name)
@@ -340,6 +345,8 @@ wait_till_object_state_contains (Accessible *object, int control_type, FILE *log
 		for (i = 0; i < count; i++) {
 			object_state = AccessibleStateSet_contains (state,
 								    state_list [control_type].states [i]);
+			if (ldtp_debug)
+				g_print ("Object state: %d - %d\n", i, object_state);
 			if (object_state == FALSE) {
 				flag = FALSE;
 				break;
@@ -368,6 +375,19 @@ wait_till_object_state_contains (Accessible *object, int control_type, FILE *log
 	return -1;
 }
 
+static void
+window_info_added_hashtable (char *window_name, LDTPClientContext* cctxt, LDTPErrorCode* err)
+{
+	if (!cctxt || !window_name)
+		*err = LDTP_ERROR_ARGUMENT_NULL;
+
+	if (!client_context)
+		client_context = g_hash_table_new_full (&g_str_hash, &g_str_equal, key_destroy_func, NULL);
+
+	g_hash_table_insert (client_context, g_strdup ((gchar *)window_name), cctxt);
+	*err = LDTP_ERROR_SUCCESS;
+}
+
 /*
   Get accessible handle of the given application
 */
@@ -561,7 +581,6 @@ get_accessible_context_handle (Accessible *app_handle, char *context)
 			child = Accessible_getChildAtIndex (app_handle, i);
 			if (!child)
 				continue;
-			//child_name = Accessible_getName (child);
 			/*
 			  Application name of child handle
 			*/
@@ -569,12 +588,12 @@ get_accessible_context_handle (Accessible *app_handle, char *context)
 			role = Accessible_getRole (child);
 			if (child_name) {
 				g_print ("child_name: %s\n", child_name);
-				window_name = get_window_text_in_appmap_format (child_name, role);
+				window_name = get_window_name_in_appmap_format (child_name, role);
 			}
 			if (!window_name) {
 				gchar *tmp = g_strdup_printf ("%ld", j++);
 				if (tmp) {
-					window_name = get_window_text_in_appmap_format (tmp, role);
+					window_name = get_window_name_in_appmap_format (tmp, role);
 					g_free (tmp);
 					tmp = NULL;
 				}
@@ -594,7 +613,7 @@ get_accessible_context_handle (Accessible *app_handle, char *context)
 						window_name = NULL;
 					}
 					if (tmp) {
-						window_name = get_window_text_in_appmap_format (tmp, role);
+						window_name = get_window_name_in_appmap_format (tmp, role);
 						g_free (tmp);
 						tmp = NULL;
 					}
@@ -725,7 +744,7 @@ get_accessible_component_handle (struct node *head, Accessible *context, FILE *l
 		if (role) {
 			char *name = Accessible_getName (child);
 			if (ldtp_debug && name)
-				g_print ("Role: %s - %s\n", role, name);
+				g_print ("Role: %s - %s %d - %ld\n", role, name, __LINE__, i);
 			SPI_freeString (role);
 			SPI_freeString (name);
 		}
@@ -824,7 +843,7 @@ is_object_matching (Accessible *object, GHashTable *comp_attributes, FILE *log_f
 		accessible_label = Accessible_getName (object);
 		role = Accessible_getRoleName (object);
 		if (role) {
-			g_print ("Role: %s\n", role);
+			g_print ("Role: %s %d\n", role, __LINE__);
 			SPI_freeString (role);
 		}
 		g_print ("Label: %s - %s\n", hash_label, accessible_label);
@@ -971,12 +990,12 @@ get_child_window_handle (Accessible *app_handle, char *context, char **window_na
 		role = Accessible_getRole (child);
 		if (name) {
 			g_print ("child_name: %s\n", name);
-			*window_name = get_window_text_in_appmap_format (name, role);
+			*window_name = get_window_name_in_appmap_format (name, role);
 		}
 		if (!*window_name) {
 			gchar *tmp = g_strdup_printf ("%ld", j++);
 			if (tmp) {
-				*window_name = get_window_text_in_appmap_format (tmp, role);
+				*window_name = get_window_name_in_appmap_format (tmp, role);
 				g_free (tmp);
 				tmp = NULL;
 			}
@@ -996,7 +1015,7 @@ get_child_window_handle (Accessible *app_handle, char *context, char **window_na
 					*window_name = NULL;
 				}
 				if (tmp) {
-					*window_name = get_window_text_in_appmap_format (tmp, role);
+					*window_name = get_window_name_in_appmap_format (tmp, role);
 					g_free (tmp);
 					tmp = NULL;
 				}
@@ -1129,7 +1148,7 @@ update_cur_window_appmap_handle (LDTPClientContext* cctxt,
 		if (ldtp_debug && parent_name)
 			g_print ("Parent name: %s\n", parent_name);
 		role = Accessible_getRole (parent) == SPI_ROLE_APPLICATION ? SPI_ROLE_APPLICATION : Accessible_getRole (child);
-		window_name = get_window_text_in_appmap_format (parent_name, role);
+		window_name = get_window_name_in_appmap_format (parent_name, role);
 		if (ldtp_debug && window_name && parent_name)
 			g_print ("Window name - Stripped: %s - %s\n", window_name, parent_name);
 		SPI_freeString (parent_name);
@@ -1169,6 +1188,9 @@ update_cur_window_appmap_handle (LDTPClientContext* cctxt,
 			pthread_mutex_lock (&mutex);
 			g_hash_table_replace (cctxt->app_map, g_strdup (cctxt->window_name), new_hashtable);
 			pthread_mutex_unlock (&mutex);
+			pthread_mutex_lock (&cb_mutex);
+			window_info_added_hashtable (cctxt->window_name, cctxt, err);
+			pthread_mutex_unlock (&cb_mutex);
 			if (window_name && window_name != cctxt->window_name) {
 				g_free (window_name);
 				window_name = NULL;
@@ -1188,9 +1210,6 @@ update_cur_window_appmap_handle (LDTPClientContext* cctxt,
 		return;
 	}
 	if (ldtp_debug) {
-		/*
-		  Enable it for debugging purpose
-		*/
 		g_hash_table_foreach (cctxt->app_map, (GHFunc)&print_context, NULL);
 	}
 	*err = LDTP_ERROR_SUCCESS;
@@ -1256,6 +1275,7 @@ ldtp_gui_get_gui_handle (LDTPClientContext* cctxt,
 	gchar *context    = NULL;
 	char *app_name    = NULL;
 	char *component   = NULL;
+	char *class_type  = NULL;
 	char *window_prop = NULL;
 	struct node *head;
 	gboolean flag = FALSE;
@@ -1336,7 +1356,7 @@ ldtp_gui_get_gui_handle (LDTPClientContext* cctxt,
 			}
 			/*
 			name = Accessible_getName (child);
-			window_name = get_window_text_in_appmap_format (name, Accessible_getRole (child));
+			window_name = get_window_name_in_appmap_format (name, Accessible_getRole (child));
 			*/
 			Accessible_unref (child);
 			if (cctxt->window_name) {
@@ -1377,7 +1397,7 @@ ldtp_gui_get_gui_handle (LDTPClientContext* cctxt,
 	if (app_name)
 		g_print ("app_name: %s\n", app_name);
 	window_prop = get_property (cur_component, "label", cctxt->log_fp);
-	if (window_prop)
+	if (ldtp_debug && window_prop)
 		g_print ("window_prop: %s\n", window_prop);
 
 	if (context && component &&
@@ -1404,6 +1424,7 @@ ldtp_gui_get_gui_handle (LDTPClientContext* cctxt,
 			}
 
 			while (difftime (cur, start) < time_wait) {
+				g_print ("Updating appmap - context\n");
 				update_cur_window_appmap_handle (cctxt, err);
 				updated_appmap = TRUE;
 				cur_window = get_object_def (cctxt->app_map, context, cctxt->log_fp, TRUE);
@@ -1483,12 +1504,45 @@ ldtp_gui_get_gui_handle (LDTPClientContext* cctxt,
 	    !g_utf8_collate ((const gchar *)context, (const gchar *)component))
 		return ctxt_handle;
 
-	head = trace_path_to_parent (cur_window, context, cur_component, cctxt->log_fp, cctxt, err);
+	head = trace_path_to_parent (cur_window, context, cur_component, &class_type, cctxt->log_fp, cctxt, err);
 	component_handle = get_accessible_component_handle (head, context_handle, cctxt->log_fp);
 	Accessible_unref (context_handle);
 	ctxt_handle->handle = NULL;
 	g_free (head);
 
+	if (component_handle) {
+		char *role = Accessible_getRoleName (component_handle);
+		if (role) {
+			char *str1 = NULL;
+			char *str2 = NULL;
+			if (g_utf8_strchr (role, -1, ' ') != NULL) {
+				str1 = escape_character (role, ' ');
+			} else {
+				str1 = g_strdup (role);
+			}
+			if (class_type && g_utf8_strchr (class_type, -1, '_') != NULL) {
+				str2 = escape_character (class_type, '_');
+			} else {
+				str2 = g_strdup (class_type);
+			}
+			if (str1 && str2) {
+				if (ldtp_debug)
+					g_print ("str1: %s - str2: %s\n", str1, str2);
+				if (g_utf8_collate (str1, str2) != 0) {
+					// Role types are not same, so we need to rescan
+					Accessible_unref (component_handle);
+					component_handle = NULL;
+				}
+			}
+			if (str1)
+				g_free (str1);
+			if (str2)
+				g_free (str2);
+			SPI_freeString (role);
+		}
+		class_type = NULL;
+	}
+
 	if (!component_handle || Accessible_getRole (component_handle) == SPI_ROLE_UNKNOWN) {
 		int time_wait = ldtp_obj_timeout;
 		time_t start, cur;
@@ -1511,7 +1565,7 @@ ldtp_gui_get_gui_handle (LDTPClientContext* cctxt,
 			/*
 			  To avoid runtime remap function to be called, let us call remap here
 			*/
-			g_print ("Updating appmap\n");
+			g_print ("Updating appmap - component\n");
 			if (cctxt->window_name) {
 				g_free (cctxt->window_name);
 				cctxt->window_name = NULL;
@@ -1525,11 +1579,44 @@ ldtp_gui_get_gui_handle (LDTPClientContext* cctxt,
 			if (context_handle) {
 				cur_window = get_object_def (cctxt->app_map, context, cctxt->log_fp, TRUE);
 				cur_component = get_object_def (cur_window, component, cctxt->log_fp, FALSE);
-				head = trace_path_to_parent (cur_window, context, cur_component, cctxt->log_fp, cctxt, err);
+				head = trace_path_to_parent (cur_window, context, cur_component,
+							     &class_type, cctxt->log_fp, cctxt, err);
 				component_handle = get_accessible_component_handle (head, context_handle, cctxt->log_fp);
 				Accessible_unref (context_handle);
 				g_free (head);
 			}
+			if (component_handle) {
+				char *role = Accessible_getRoleName (component_handle);
+				if (role) {
+					char *str1 = NULL;
+					char *str2 = NULL;
+					if (g_utf8_strchr (role, -1, ' ') != NULL) {
+						str1 = escape_character (role, ' ');
+					} else {
+						str1 = g_strdup (role);
+					}
+					if (g_utf8_strchr (class_type, -1, '_') != NULL) {
+						str2 = escape_character (class_type, '_');
+					} else {
+						str2 = g_strdup (class_type);
+					}
+					if (str1 && str2) {
+						if (ldtp_debug)
+							g_print ("str1: %s - str2: %s\n", str1, str2);
+						if (g_utf8_collate (str1, str2) != 0) {
+							// Role types are not same, so we need to rescan
+							Accessible_unref (component_handle);
+							component_handle = NULL;
+						}
+					}
+					if (str1)
+						g_free (str1);
+					if (str2)
+						g_free (str2);
+					SPI_freeString (role);
+				}
+				class_type = NULL;
+			}
 			if (!component_handle || Accessible_getRole (component_handle) == SPI_ROLE_UNKNOWN) {
 				if (component_handle) {
 					Accessible_unref (component_handle);
@@ -1686,25 +1773,38 @@ get_child_object_type (Accessible *accessible)
 	int i;
 	int num_child;
 	int child_type;
+	char *role_name;
 	AccessibleRole role;
 	Accessible *child;
                                                                                 
 	num_child = Accessible_getChildCount (accessible);
+	if (ldtp_debug) {
+		role_name = Accessible_getRoleName (accessible);
+		g_print ("Child object type: %s\n", role_name);
+		SPI_freeString (role_name);
+	}
+                                                  
 	for (i = 0; i < num_child; i++) {
 		child = Accessible_getChildAtIndex (accessible, i);
 		if (!child)
 			continue;
-                                                                                
+
+		if (ldtp_debug) {
+			role_name = Accessible_getRoleName (child);
+			g_print ("Child object type: %s\n", role_name);
+			SPI_freeString (role_name);
+		}
+
 		role = Accessible_getRole (child);
 		if (role == SPI_ROLE_MENU) {
 			Accessible_unref (child);
 			return SPI_ROLE_MENU;
-		}
-		else if (role == SPI_ROLE_LIST) {
+		} else if (role == SPI_ROLE_LIST) {
+			g_print ("Role: %d\n", SPI_ROLE_LIST);
 			Accessible_unref (child);
 			return SPI_ROLE_LIST;
 		}
-                                                                                
+
 		child_type = get_child_object_type (child);
 		if (child_type != 0) {
 			Accessible_unref (child);
