@@ -19,8 +19,8 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110, USA.
  */
 
 #include "ldtp.h"
@@ -40,10 +40,12 @@ gboolean ldtp_debug   = FALSE;
 static gboolean ldtp_usage   = FALSE;
 static gboolean ldtp_version = FALSE;
 gboolean ldtp_script_service = FALSE;
-GHashTable *event_notifier  = NULL;
-static GHashTable *client_thread_pool = NULL;
+GHashTable *event_notifier = NULL;
+GHashTable *client_context = NULL;
+GHashTable *client_thread_pool = NULL;
 static AccessibleEventListener *window_listener;
 pthread_mutex_t cb_mutex = PTHREAD_MUTEX_INITIALIZER;
+pthread_mutex_t client_thread_pool_mutex = PTHREAD_MUTEX_INITIALIZER;
 
 static GOptionEntry entries[] = 
 	{
@@ -69,18 +71,36 @@ is_window_reg_for_events (char *context)
 	return cctxt;
 }
 
+static LDTPClientContext*
+is_window_in_cctxt (char *window_name)
+{
+	LDTPClientContext *cctxt = NULL;
+	if (client_context) {
+		cctxt = g_hash_table_find (client_context, search_title_based, window_name);
+		if (cctxt && window_name)
+			g_print ("Registered window title: %s\n", window_name);
+	}
+	return cctxt;
+}
+
 static void
 report_window_event  (const AccessibleEvent *event, void *user_data)
 {
-	char *title, *context = Accessible_getName (event->source);
-	title = AccessibleWindowEvent_getTitleString (event);
-
-	if (title && event_notifier) {
+	g_print ("Event type: %s\n", event->type);
+	if (event_notifier && g_ascii_strcasecmp ("window:create", event->type) == 0) {
 		uint32_t resp_size = 0;
 		LDTPErrorCode status;
 		char *resp_pckt = NULL;
 		char *window_name = NULL;
 		LDTPClientContext *cctxt = NULL;
+
+		char *context = Accessible_getName (event->source);
+		char *title = AccessibleWindowEvent_getTitleString (event);
+		if (!title) {
+			if (context)
+				SPI_freeString (context);
+			return;
+		}
 		pthread_mutex_lock (&cb_mutex);
 		if ((cctxt = is_window_reg_for_events (title))) {
 			/*
@@ -112,7 +132,7 @@ report_window_event  (const AccessibleEvent *event, void *user_data)
 		/*
 		  If window title is used in old appmap format (like dlgFind), then use the following approach
 		*/
-		window_name = get_window_text_in_appmap_format (title, Accessible_getRole (event->source));
+		window_name = get_window_name_in_appmap_format (title, Accessible_getRole (event->source));
 		if (window_name && is_window_reg_for_events (window_name)) {
 			/*
 			  Notify to client
@@ -136,9 +156,36 @@ report_window_event  (const AccessibleEvent *event, void *user_data)
 		if (window_name)
 			g_free (window_name);
 		pthread_mutex_unlock (&cb_mutex);
+		SPI_freeString (context);
+		SPI_freeString (title);
+	} else if (g_ascii_strcasecmp ("window:destroy", event->type) == 0) {
+		LDTPClientContext *cctxt = NULL;
+		char *title = AccessibleWindowEvent_getTitleString (event);
+		char *window_name;
+		if (!title) {
+			g_print ("Window title NULL\n");
+			return;
+		}
+		window_name = get_window_name_in_appmap_format (title, Accessible_getRole (event->source));
+		if (window_name) {
+			g_print ("Window name: %s - %s\n", window_name, title);
+			pthread_mutex_lock (&cb_mutex);
+			cctxt = is_window_in_cctxt (window_name);
+			if (cctxt) {
+				GHashTable *context = NULL;
+				if (cctxt->app_map)
+					context = g_hash_table_lookup (cctxt->app_map, window_name);
+				if (context) {
+					g_hash_table_foreach_remove (context, (GHRFunc)&remove_context_entries, context);
+					g_hash_table_destroy (context);
+					g_hash_table_remove (cctxt->app_map, window_name);
+					context = NULL;
+				}
+			}
+			pthread_mutex_unlock (&cb_mutex);
+		}
+		SPI_freeString (title);
 	}
-	SPI_freeString (context);
-	SPI_freeString (title);
 }
 
 static void
@@ -157,21 +204,14 @@ cleanup (int mysig)
 	if (leaked)
 		printf ("Leaked %d SPI handles\n", leaked);
 
+	pthread_mutex_lock (&client_thread_pool_mutex);
 	g_hash_table_foreach (client_thread_pool, signal_all_threads, NULL);
+	client_thread_pool = NULL;
+	pthread_mutex_unlock (&client_thread_pool_mutex);
 	/*
 	  Close server socket
 	*/
 	close_connection (get_server_socket (LDTP_SCRIPT_SERVER));
-	close_connection (get_server_socket (LDTP_RECORD_SERVER));
-
-	tmpfile = get_tmp_file (LDTP_RECORD_SERVER);
-	if (tmpfile) {
-		/*
-		  Remove tmp file
-		*/
-		unlink (tmpfile);
-		g_free (tmpfile);
-	}
 
 	if (ldtp_script_service || ldtp_script_port)
 		goto quit;
@@ -216,7 +256,7 @@ accept_connection (int listener, LDTPErrorCode* err)
 
 	newfd_dup = malloc (sizeof (newfd));
 	*newfd_dup = newfd;
-	retval = pthread_create (&client_thread, NULL, (void *)&handle_client, 
+	retval = pthread_create (&client_thread, NULL, &handle_client, 
 				 (void *)newfd_dup);
 	if (retval == EAGAIN) {
 		/* unable to create threads... kindly retry... */
@@ -227,8 +267,12 @@ accept_connection (int listener, LDTPErrorCode* err)
 		goto error;
 	}
 	else {
+		char fd [15];
 		/* parent process */
-		g_hash_table_insert (client_thread_pool, &newfd, &client_thread);
+		pthread_mutex_lock (&client_thread_pool_mutex);
+		sprintf (fd, "%d", newfd);
+		g_hash_table_insert (client_thread_pool, g_strdup (fd), NULL);
+		pthread_mutex_unlock (&client_thread_pool_mutex);
 		*err = LDTP_ERROR_SUCCESS;
 		return;
 	}
@@ -239,9 +283,29 @@ accept_connection (int listener, LDTPErrorCode* err)
 	return;
 }
 
+static gboolean
+is_fd_in_client_pool (gpointer key,
+		      gpointer value,
+		      gpointer user_data)
+{
+	if (key && user_data) {
+		if (g_utf8_collate (key, user_data) == 0)
+			return TRUE;
+	}
+	return FALSE;
+}
+
 void 
 close_connection (int fd)
 {
+	if (client_thread_pool) {
+		char tmpfd [15];
+		pthread_mutex_lock (&client_thread_pool_mutex);
+		sprintf (tmpfd, "%d", fd);
+		g_hash_table_foreach_remove (client_thread_pool, (GHRFunc)&is_fd_in_client_pool, tmpfd);
+		pthread_mutex_unlock (&client_thread_pool_mutex);
+	}
+
 	close (fd);
 }
 
@@ -256,35 +320,29 @@ init_pollfd (int fd, struct pollfd *pfd, LDTPErrorCode *err)
 	pfd->fd = fd;
 	pfd->events = POLLIN;
 
-	if (!client_thread_pool)
-		client_thread_pool = g_hash_table_new (&g_int_hash, &g_int_equal);
+	if (!client_thread_pool) {
+		pthread_mutex_lock (&client_thread_pool_mutex);
+		client_thread_pool = g_hash_table_new_full (&g_str_hash, &g_str_equal, &key_destroy_func, NULL);
+		pthread_mutex_unlock (&client_thread_pool_mutex);
+	}
 	*err = LDTP_ERROR_SUCCESS;
 }
 
-static void
+static void *
 ldtp_server_thread (void *ptr)
 {
-	struct pollfd pfd[2];
-	int record_socket;
+	struct pollfd pfd;
 	int server_socket;
 	int client_update_flag;
+	int time_out = -1;
 	LDTPErrorCode err;
 
-	server_socket = init_ldtp_server (LDTP_SCRIPT_SERVER);
-	record_socket = init_ldtp_server (LDTP_RECORD_SERVER);
-
-	init_pollfd (server_socket, &pfd[0], &err);
-	if (err != LDTP_ERROR_SUCCESS) {
-		/* 
-		   1) Close the server
-		   2) Inform SPI_Main() to close, in some way
-		   may be SPI_Quit()?
-		*/
-		close_connection (server_socket);
-		pthread_exit ((void *) 1);
+	if (!ldtp_script_service && !ldtp_script_port) {
+		time_out = 1000 * 60 * 5; // Wait max of 5 minutes, if no clients then quit
 	}
+	server_socket = init_ldtp_server (LDTP_SCRIPT_SERVER);
 
-	init_pollfd (record_socket, &pfd[1], &err);
+	init_pollfd (server_socket, &pfd, &err);
 	if (err != LDTP_ERROR_SUCCESS) {
 		/* 
 		   1) Close the server
@@ -296,7 +354,7 @@ ldtp_server_thread (void *ptr)
 	}
 
 	while (1) {
-		if (poll (pfd, 2, -1) == -1) {
+		if (poll (&pfd, 1, time_out) == -1) {
 			if (errno == EINTR) {
 				continue;
 			}
@@ -310,16 +368,25 @@ ldtp_server_thread (void *ptr)
 			}
 		}
 		client_update_flag = 0;
-		if ((pfd[0].revents & POLLIN) && (pfd[0].fd == server_socket)) {
+		if ((pfd.revents & POLLIN) && (pfd.fd == server_socket)) {
 			accept_connection (server_socket, &err);
 			if (err != LDTP_ERROR_SUCCESS)
 				ldtp_log ("******Unable to accept connection*******\n");
+			continue;
 		} // if check for all fds
-		if ((pfd[1].revents & POLLIN) && (pfd[1].fd == record_socket)) {
-			accept_connection (record_socket, &err);
-			if (err != LDTP_ERROR_SUCCESS)
-				ldtp_log ("******Unable to accept connection*******\n");
-		} // if check for all fds
+		if (client_thread_pool) {
+			guint size;
+			pthread_mutex_lock (&client_thread_pool_mutex);
+			size = g_hash_table_size (client_thread_pool);
+			if (ldtp_debug && size)
+				g_print ("Clients: %d\n", size);
+			if (size == 0) {// Let us break
+				pthread_mutex_unlock (&client_thread_pool_mutex);
+				cleanup (0);
+				break;
+			}
+			pthread_mutex_unlock (&client_thread_pool_mutex);
+		}
 	} // while loop forever
 	pthread_exit ((void *) 0);
 }
@@ -356,7 +423,7 @@ main (int argc, char **argv)
 	g_option_context_free (context);
 
 	if (ldtp_usage) {
-		printf ("ldtp [--verbose] [--gui-timeout=N]  [--obj-timeout=N] [--version] [--help]\n");
+		printf ("ldtp [--script-engine] [--port=N] [--verbose] [--gui-timeout=N]  [--obj-timeout=N] [--version] [--help]\n");
 		exit (0);
 	}
 	if (ldtp_version) {
@@ -392,7 +459,7 @@ main (int argc, char **argv)
 			ldtp_obj_timeout = 5;
 	}
 
-	retval = pthread_create (&server_thread, NULL, (void *)&ldtp_server_thread, 
+	retval = pthread_create (&server_thread, NULL, &ldtp_server_thread, 
 				 NULL);
 	if (retval == EAGAIN) {
 		/* unable to create threads... kindly retry... */
@@ -406,6 +473,8 @@ main (int argc, char **argv)
 
 	SPI_registerGlobalEventListener (window_listener,
 					 "window:create");
+	SPI_registerGlobalEventListener (window_listener,
+					 "window:destroy");
 	SPI_event_main ();
 	return 0;
 }
