@@ -19,8 +19,8 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110, USA.
  */
 
 #include "ldtp.h"
@@ -28,7 +28,6 @@
 #include "ldtp-utils.h"
 #include "ldtp-error.h"
 #include "ldtp-logger.h"
-#include "ldtp-gui-cb.h"
 #include "ldtp-command.h"
 #include "ldtp-gui-comp.h"
 
@@ -145,94 +144,6 @@ list_child_menu_items (Accessible *object, FILE *log_fp)
 	}
 }
 
-void
-menu_item_cb (FILE *fp, 
-	      const AccessibleEvent *event, 
-	      char *window_name, 
-	      char *window_type, 
-	      gboolean combobox_flag,
-	      char *combobox_name)
-{
-	int  i = 0;
-	gint role;
-	char *name       = NULL;
-	char *role_name  = NULL;
-	GList *menu_item  = NULL;
-	Accessible *current_menu_item    = NULL;
-	Accessible *accessible_menu_item = NULL;
-
-	if (!fp || !event || !window_name || !window_type)
-		return;
-	g_print ("==DEBUG== Inside record menu\n");
-	if (combobox_flag == FALSE) {
-		current_menu_item = accessible_menu_item = event->source;
-		role = Accessible_getRole (accessible_menu_item);
-		if (role != SPI_ROLE_MENU_ITEM &&
-		    role != SPI_ROLE_CHECK_MENU_ITEM &&
-		    role != SPI_ROLE_RADIO_MENU_ITEM) /*If current level doesn't, then no need to proceed*/
-			return;
-		for (i = 0; role == SPI_ROLE_MENU ||
-			     role == SPI_ROLE_MENU_ITEM ||
-			     role == SPI_ROLE_CHECK_MENU_ITEM ||
-			     role == SPI_ROLE_RADIO_MENU_ITEM; i++) {
-			name = Accessible_getName (current_menu_item);
-			menu_item = g_list_append (menu_item , g_strdup(name));
-			SPI_freeString (name);
-			if (current_menu_item != accessible_menu_item) {
-				Accessible *tmp = NULL;
-				tmp = Accessible_getParent (current_menu_item);
-				if (current_menu_item != event->source)
-					Accessible_unref (current_menu_item);
-				current_menu_item = tmp;
-			}
-			else
-				current_menu_item = Accessible_getParent (accessible_menu_item);
-			if (current_menu_item)
-				role = Accessible_getRole (current_menu_item);
-		}
-		if (current_menu_item && current_menu_item != accessible_menu_item)
-			Accessible_unref (current_menu_item);
-
-		if (i == 0) /* Means no navigation in the above for loop*/
-			return;
-		role_name = Accessible_getRoleName (event->source);
-		fprintf (fp, "<COMMAND><ACTION>SELECTMENU</ACTION>");
-		fprintf (fp, "<WINDOW>%s</WINDOW>", window_type);
-		fprintf (fp, "<OBJECTTYPE>%s</OBJECTTYPE>", role_name);
-		fprintf (fp, "<CONTEXT>%s</CONTEXT><COMPONENT>", window_name);
-		fflush (fp);
-		SPI_freeString (role_name);
-		/*
-		 * variable i will be now number of menu items + 1. 
-		 * so first reduce i by 1 and then access the menu_item list
-		 */
-		for (i = i - 1; i >= 0; i--) {
-			if (i != 0) {
-				fprintf (fp, "%s;", (char *)g_list_nth_data (menu_item, i));
-			}
-			else {
-				fprintf (fp, "%s</COMPONENT>", (char *)g_list_nth_data (menu_item, i));
-			}
-		}
-		fprintf (fp, "</COMMAND>\n");
-		// Free the variables used 
-		g_list_free (menu_item);
-	}
-	else if (combobox_name) {
-		name = Accessible_getName (event->source);
-		if (name) {
-			fprintf (fp, "<COMMAND><ACTION>COMBOSELECT</ACTION>");
-			fprintf (fp, "<WINDOW>%s</WINDOW>",window_type);
-			fprintf (fp, "<OBJECTTYPE>combo box</OBJECTTYPE>");
-			fprintf (fp, "<CONTEXT>%s</CONTEXT>", window_name);
-			fprintf (fp, "<COMPONENT>%s</COMPONENT>", combobox_name);
-			fprintf (fp, "<ARGUMENTS><ARGUMENT>%s</ARGUMENT></ARGUMENTS></COMMAND>\n", name);
-			fflush (fp);
-			SPI_freeString (name);
-		}
-	}
-}
-
 LDTPErrorCode
 menu_item_main (LDTPClientContext* cctxt, int command)
 {
