@@ -20,8 +20,8 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110, USA.
  */
 
 #include "ldtp.h"
@@ -100,13 +100,12 @@ list_child_menu_items (Accessible *object, char **data, FILE *log_fp)
 				Accessible_unref (child);
 			}
 		}
-	}
-	else {
-		error =  (LDTP_ERROR_MENU_ITEM_DOES_NOT_EXIST);
+	} else {
+		error = LDTP_ERROR_MENU_ITEM_DOES_NOT_EXIST;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		return error;
 	}
-	return  (LDTP_ERROR_SUCCESS);
+	return LDTP_ERROR_SUCCESS;
 }
 
 static LDTPErrorCode
@@ -147,19 +146,17 @@ select_popup_menu (LDTPClientContext* cctxt)
 				Accessible_unref (menu_item);
 				SPI_freeString (name);
 			}
-			error =  (LDTP_ERROR_MENU_ITEM_DOES_NOT_EXIST);
+			error = LDTP_ERROR_MENU_ITEM_DOES_NOT_EXIST;
 			log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), cctxt->log_fp);
-		}
-		else {
-			error =  (LDTP_ERROR_UNABLE_TO_GET_MENU_HANDLE);
+		} else {
+			error = LDTP_ERROR_UNABLE_TO_GET_MENU_HANDLE;
 			log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), cctxt->log_fp);
 			Accessible_unref (pop_menu);
 		}
 		Accessible_unref (menu);
 		return error;
-	}
-	else {
-		error =  (LDTP_ERROR_UNABLE_TO_FIND_POPUP_MENU);
+	} else {
+		error = LDTP_ERROR_UNABLE_TO_FIND_POPUP_MENU;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), cctxt->log_fp);
 	}
 	Accessible_unref (pop_menu);
@@ -205,7 +202,7 @@ menu_main (LDTPClientContext* cctxt, int command, char *window_name)
 					   __FILE__, __LINE__);
 			g_print ("%s\n", msg);
 			log_msg (LDTP_LOG_CAUSE, msg, cctxt->log_fp);
-			return  (LDTP_ERROR_UNABLE_TO_GET_CHILD_MENU_ITEM);
+			return LDTP_ERROR_UNABLE_TO_GET_CHILD_MENU_ITEM;
 		}
 		ldtp_req = cctxt->req;
 
@@ -257,7 +254,7 @@ menu_main (LDTPClientContext* cctxt, int command, char *window_name)
 					   __FILE__, __LINE__);
 			g_print ("%s\n", msg);
 			log_msg (LDTP_LOG_CAUSE, msg, cctxt->log_fp);
-			return  (LDTP_ERROR_UNABLE_TO_GET_CHILD_MENU_ITEM);
+			return LDTP_ERROR_UNABLE_TO_GET_CHILD_MENU_ITEM;
 		}
 		class = Accessible_getRole (accessible->handle);
 		cctxt->gui_handle->handle = accessible->handle;
@@ -265,9 +262,9 @@ menu_main (LDTPClientContext* cctxt, int command, char *window_name)
 			error = menu_main (cctxt, command, window_name);
 		else if ((command == LDTP_CMD_DOESMENUITEMEXIST) && class == SPI_ROLE_MENU_ITEM) {
 			if (accessible)
-				error =  (LDTP_ERROR_SUCCESS);
+				error = LDTP_ERROR_SUCCESS;
 			else
-				error =  (LDTP_ERROR_MENU_ITEM_DOES_NOT_EXIST);
+				error = LDTP_ERROR_MENU_ITEM_DOES_NOT_EXIST;
 		}
 		else if (class == SPI_ROLE_MENU_ITEM)
 			error = menu_item_main (cctxt, command);
@@ -289,13 +286,13 @@ menu_main (LDTPClientContext* cctxt, int command, char *window_name)
 		if (error == LDTP_ERROR_SUCCESS && cctxt->resp->data)
 			cctxt->resp->data_len = g_utf8_strlen (cctxt->resp->data, -1);
 		if (cctxt->resp->data)
-			g_print ("\nSubmenus: %s - %d\n", cctxt->resp->data, cctxt->resp->data_len);
+			g_print ("\nSubmenus: %s - %o\n", cctxt->resp->data, cctxt->resp->data_len);
 		break;
 	case LDTP_CMD_SELECTPOPUPMENU:
 		error = select_popup_menu (cctxt);
 		break;
 	default:
-		error =  (LDTP_ERROR_COMMAND_NOT_IMPLEMENTED);
+		error = LDTP_ERROR_COMMAND_NOT_IMPLEMENTED;
 		break;
 	}
 	return error;
