@@ -19,15 +19,14 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110, USA.
  */
 
 #include "ldtp.h"
 #include "ldtp-gui.h"
 #include "ldtp-error.h"
 #include "ldtp-logger.h"
-#include "ldtp-gui-cb.h"
 #include "ldtp-command.h"
 #include "ldtp-gui-comp.h"
 
@@ -95,35 +94,6 @@ click (Accessible *object, FILE *log_fp)
 	}
 }
 
-/*
-  push_button_cb function is used in ldtp-record.c to record the push_button events 
-*/
-void
-push_button_cb (FILE *fp, const AccessibleEvent *event,
-		char *window_name, char *window_type)
-{
-	char *name = NULL;
-	char *role = NULL;
-
-	g_print ("DEBUG = Pushbutton callback\n");
-
-	if (!fp || !event || !window_name || !window_type)
-		return;
-
-	name = Accessible_getName (event->source);
-	role = Accessible_getRoleName (event->source);
-	if (name && role) {
-		fprintf (fp,
-			 "<COMMAND><ACTION>CLICK</ACTION><WINDOW>%s</WINDOW><OBJECTTYPE>%s</OBJECTTYPE><CONTEXT>%s</CONTEXT><COMPONENT>%s</COMPONENT></COMMAND>\n", 
-			 window_type, 
-			 role,
-			 window_name,
-			 name);
-	}
-	SPI_freeString (name);
-	SPI_freeString (role);
-}
-
 LDTPErrorCode
 push_button_main (LDTPClientContext* cctxt, int command)
 {
