@@ -20,8 +20,8 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110, USA.
  */
 
 #include "ldtp.h"
@@ -49,6 +49,7 @@ static int table = 0,
 	tbutton = 0,
 	radio_button = 0,
 	check_box = 0,
+	tree = 0,
 	tree_table = 0,
 	layered_pane = 0,
 	text = 0,
@@ -57,6 +58,7 @@ static int table = 0,
 	filler = 0,
 	menubar = 0,
 	menu = 0,
+	list = 0,
 	separator = 0,
 	scroll_bar = 0,
 	scroll_pane = 0,
@@ -85,6 +87,7 @@ reset_count()
 	button = 0;
 	tbutton = 0;
 	radio_button = 0;
+	tree = 0;
 	tree_table = 0;
 	layered_pane = 0;
 	text = 0;
@@ -93,6 +96,7 @@ reset_count()
 	filler = 0;
 	menubar = 0;
 	menu = 0;
+	list = 0;
 	separator = 0;
 	scroll_bar = 0;
 	scroll_pane = 0;
@@ -365,7 +369,7 @@ filter_appmap_data (Accessible *accessible, OBJECT_INFO *obj_info, char *label)
 			parent_type = Accessible_getRole (parent);
 			Accessible_unref (parent);
 		}
-		if (parent_type == SPI_ROLE_TABLE || 
+		if (parent_type == SPI_ROLE_TABLE || parent_type == SPI_ROLE_TREE ||
 		    parent_type == SPI_ROLE_TREE_TABLE)
 			return FALSE;
 		else
@@ -431,6 +435,12 @@ get_object_info (Accessible *accessible)
 		radio_button++;
 		obj_info->object_type = g_strdup ("radio_button");
 	}
+	else if (role == SPI_ROLE_TREE) {
+		obj_info->prefix = g_strdup ("tree");
+		obj_info->instance_index = tree;
+		tree++;
+		obj_info->object_type = g_strdup ("tree");
+	}
 	else if (role == SPI_ROLE_TREE_TABLE) {
 		obj_info->prefix = g_strdup ("ttbl");
 		obj_info->instance_index = tree_table;
@@ -509,6 +519,12 @@ get_object_info (Accessible *accessible)
 		obj_info->instance_index = -1;
 		obj_info->object_type = g_strdup ("list_item");
 	}
+	else if (role == SPI_ROLE_LIST) {
+		obj_info->prefix = g_strdup ("lst");
+		obj_info->instance_index = list;
+		list++;
+		obj_info->object_type = g_strdup ("list");
+	}
 	else if (role == SPI_ROLE_CHECK_MENU_ITEM) {
 		obj_info->prefix = g_strdup ("mnu");
 		obj_info->instance_index = menu;
@@ -552,6 +568,28 @@ get_object_info (Accessible *accessible)
 		text++;
 		obj_info->object_type = g_strdup ("text");
 	}
+#ifdef ENABLE_NEWROLES
+	else if (role == SPI_ROLE_ENTRY) {
+		obj_info->prefix = g_strdup ("txt");
+		obj_info->instance_index = text;
+		text++;
+		obj_info->object_type = g_strdup ("entry");
+	}
+#endif
+	/*
+	else if (role == SPI_ROLE_AUTOCOMPLETE) {
+		obj_info->prefix = g_strdup ("txt");
+		obj_info->instance_index = text;
+		text++;
+		obj_info->object_type = g_strdup ("auto_complete");
+	}
+	*/
+	else if (role == SPI_ROLE_PARAGRAPH) {
+		obj_info->prefix = g_strdup ("txt");
+		obj_info->instance_index = text;
+		text++;
+		obj_info->object_type = g_strdup ("paragraph");
+	}
 	else if (role == SPI_ROLE_PASSWORD_TEXT) {
 		obj_info->prefix = g_strdup ("txt");
 		obj_info->instance_index = text;
@@ -661,7 +699,7 @@ get_object_info (Accessible *accessible)
 				obj_info->prefix = g_strdup ("ukn");
 				obj_info->instance_index = unknown;
 				unknown++;
-				obj_info->object_type = g_strdup ("unknown");
+				obj_info->object_type = g_strdup (name);
 			}
 			SPI_freeString (name);
 		}
@@ -673,10 +711,16 @@ get_object_info (Accessible *accessible)
 		}
 	}
 	else {
+		char *name;
 		obj_info->prefix = g_strdup ("ukn");
 		obj_info->instance_index = unknown;
 		unknown++;
-		obj_info->object_type = g_strdup ("unknown");
+		name = Accessible_getRoleName (accessible);
+		if (name) {
+			obj_info->object_type = g_strdup (name);
+			SPI_freeString (name);
+		} else
+			obj_info->object_type = g_strdup ("unknown");
 	}
 	return obj_info;
 }
@@ -1085,8 +1129,8 @@ accessible_object_handle (Accessible *accessible, char *parent_name,
 	}
 }
 
-char *
-get_window_text_in_appmap_format (char *window_name, AccessibleRole role)
+char*
+get_window_name_in_appmap_format (char *window_name, AccessibleRole role)
 {
 	char *type = NULL;
 	char *retval = NULL;
