@@ -19,8 +19,8 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110, USA.
  */
 
 #ifndef __REMAP_H__
@@ -30,6 +30,6 @@ gchar *strip_delim (const gchar *text, gchar ch);
 GHashTable *do_remap (Accessible *accessible, char *name, GHashTable *context,
 		      GHashTable *context_attributes, gboolean locale_flag,
 		      gboolean overloadedWindowName, gboolean remap_context); 
-char *get_window_text_in_appmap_format (char *window_name, AccessibleRole role);
+char *get_window_name_in_appmap_format (char *window_name, AccessibleRole role);
 
 #endif
