@@ -19,17 +19,17 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110, USA.
  */
 
 #include "ldtp.h"
 #include "ldtp-gui.h"
 #include "ldtp-error.h"
 #include "ldtp-logger.h"
-#include "ldtp-gui-cb.h"
 #include "ldtp-command.h"
 #include "ldtp-gui-comp.h"
+#include "ldtp-utils.h"
 
 extern gint ldtp_obj_timeout;
 
@@ -578,7 +578,7 @@ verify_cell_value (LDTPClientContext* cctxt)
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), cctxt->log_fp);
 		return error;
 	}  
-	g_print ("Tree table - number of rows:%ld\tColumn: %ld\n", n_rows, n_cols);
+	g_print ("Table - number of rows:%ld\tColumn: %ld\n", n_rows, n_cols);
 	child_object = AccessibleTable_getAccessibleAt (table, row, column);
 
 	do { 
@@ -731,8 +731,8 @@ set_cell_value (LDTPClientContext* cctxt)
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), cctxt->log_fp);
 		return error;
 	}
-	g_print ("Tree table - number of rows:%ld\tColumn: %ld\n", n_rows, n_cols);
-                                                                                
+	g_print ("Table - number of rows:%ld\tColumn: %ld\n", n_rows, n_cols);
+
 	cell = AccessibleTable_getAccessibleAt (table, row, column);
 	cell = cctxt->gui_handle->handle;
 	if (Accessible_isComponent (cell)) {
@@ -1078,7 +1078,7 @@ verify_partial_cell_value (LDTPClientContext* cctxt)
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), cctxt->log_fp);
 		return error;
 	}  
-	g_print ("Tree table - number of rows:%ld\tColumn: %ld\n", n_rows, n_cols);
+	g_print ("Table - number of rows:%ld\tColumn: %ld\n", n_rows, n_cols);
 	child_object = AccessibleTable_getAccessibleAt (table, row, column);
 
 	do { 
@@ -1322,66 +1322,6 @@ get_row_index (Accessible *object, GSList **l, FILE *log_fp)
 	return error;
 }
 
-void 
-table_cb (FILE *fp,
-	  LDTPClientContext *cctxt,
-	  const AccessibleEvent *event,
-	  char *window_name,
-	  char *window_type,
-	  int window_role)
-{
-	char *tmp  = NULL;
-	char *name = NULL;
-	char *role = NULL;
-	long total_rows   = 0;
-	long selected_row = 0;
-
-	long int i;
-	long int *selected_rows = NULL;
-	AccessibleTable *obj = NULL;
-
-	if (!fp || !event || !window_name || !window_type)
-		return;
-
-	tmp = Accessible_getName (event->source); 
-	role = Accessible_getRoleName (event->source);
-
-	if (tmp) {
-		name = g_strdup (tmp);
-		SPI_freeString (tmp);
-	}
-	if (name == NULL || g_ascii_strcasecmp (name, "") == 0) {
-		name = get_relation_name (event->source, NULL);
-		if (name == NULL || g_ascii_strcasecmp (name , "") == 0) {
-			name = get_name_from_hash_table (cctxt, event->source, window_name, window_role, FALSE);
-		}
-	}
-
-	if (!name || !role) {
-		g_free (name);
-		SPI_freeString (role);
-		return;
-	}
-
-	obj = Accessible_getTable (event->source);
-	selected_rows = (long int *) malloc (AccessibleTable_getNRows (obj) * sizeof (long int *));
-	total_rows = AccessibleTable_getSelectedRows (obj, &selected_rows);
-	for (i = 0; i < total_rows; i++) {
-		selected_row = *(selected_rows + i);
-		fprintf (fp,
-			 "<COMMAND><ACTION>SELECTROWINDEX</ACTION><WINDOW>%s</WINDOW><OBJECTTYPE>%s</OBJECTTYPE><CONTEXT>%s</CONTEXT><COMPONENT>%s</COMPONENT><ARGUMENTS><ARGUMENT>%ld</ARGUMENT></ARGUMENTS></COMMAND>\n", 
-			 window_type,
-			 role,
-			 window_name,
-			 name,
-			 *(selected_rows) + i);
-	}
-	SPI_freeString (role);
-	g_free (selected_rows);
-	g_free (name);
-	AccessibleTable_unref (obj);
-}
-
 /*
   Single click row
 */
