@@ -19,15 +19,14 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110, USA.
  */
 
 #include "ldtp.h"
 #include "ldtp-gui.h"
 #include "ldtp-error.h"
 #include "ldtp-logger.h"
-#include "ldtp-gui-cb.h"
 #include "ldtp-command.h"
 #include "ldtp-gui-comp.h"
 
@@ -850,28 +849,6 @@ right_click (Accessible *object)
 		return  (LDTP_ERROR_RIGHT_CLICK_FAILED);
 }
 
-void
-text_cb (FILE *fp, 
-	 const AccessibleEvent *event, 
-	 char *window_name, 
-	 char *text_role,
-	 char *window_type, 
-	 char *txt_area_name, 
-	 char *text)
-{
-	if (!fp || !event || !window_name || !window_type || !text_role || !txt_area_name || !text)
-		return;
-
-	fprintf (fp,
-		 "<COMMAND><ACTION>SETTEXTVALUE</ACTION><WINDOW>%s</WINDOW><OBJECTTYPE>%s</OBJECTTYPE><CONTEXT>%s</CONTEXT><COMPONENT>%s</COMPONENT><ARGUMENTS><ARGUMENT>%s</ARGUMENT></ARGUMENTS></COMMAND>\n", 
-		 window_type,
-		 text_role,
-		 window_name,
-		 txt_area_name,
-		 text);
-	fflush (fp);
-}
-
 LDTPErrorCode
 text_main (LDTPClientContext* cctxt, int command)
 {
