@@ -19,18 +19,19 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110, USA.
  */
 
 #include "ldtp.h"
 #include "ldtp-gui.h"
 #include "ldtp-error.h"
 #include "ldtp-logger.h"
-#include "ldtp-gui-cb.h"
 #include "ldtp-command.h"
 #include "ldtp-gui-comp.h"
 
+extern gboolean ldtp_debug;
+
 /*
   Sort column based on given index
 */  
@@ -875,16 +876,17 @@ select_last_row (Accessible *object, FILE *log_fp)
 }
 
 static LDTPErrorCode
-right_click (Accessible *object, GSList *l)
+right_click (Accessible *object, GSList *l, FILE *log_fp)
 {
 	long i, j;
+	LDTPErrorCode error;
 	gboolean flag = FALSE;
 	long n_rows, n_cols;
 	Accessible *cell;
 	AccessibleTable *table;
 	char *name = NULL;
 	char *row_text = l->data;
-	long n_matches = 0, matches = 1;
+	long n_matches = 0, matches = 0;
 	long x, y, height, width;
 
 	l = l->next;
@@ -901,16 +903,21 @@ right_click (Accessible *object, GSList *l)
 			long child_count;
 			cell = AccessibleTable_getAccessibleAt (table, i, j);
 			child_count = Accessible_getChildCount (cell);
+			g_print ("i = %ld, j = %ld, child_count: %ld\n", i, j, child_count);
 			if (child_count > 0) {
 				long i;
 				Accessible *child;
 				for (i = 0; i < child_count; i++) {
 					child = Accessible_getChildAtIndex (cell, i);
 					name = Accessible_getName (child);
+					if (ldtp_debug && name && row_text)
+						g_print ("Name: *%s* - Row: *%s*\n", name, row_text);
 					if (g_utf8_collate (name, row_text) == 0) {
+						g_print ("Matches: %ld - n_matches: %ld\n", matches, n_matches);
 						if (n_matches != matches) {
 							matches++;
 							Accessible_unref (child);
+							g_print ("Continue\n");
 							continue;
 						} 
 
@@ -932,16 +939,23 @@ right_click (Accessible *object, GSList *l)
 					SPI_freeString (name);
 					Accessible_unref (child);
 				} // for
-			} // if
-			else  {
+			} else {
 				name = Accessible_getName (cell);
+				g_print ("name: %s row_text: %s\n", name, row_text);
 				if (g_utf8_collate (name, row_text) == 0) {
 					if (Accessible_isComponent (cell)) {
 						AccessibleComponent *accessible_component;
 						accessible_component = Accessible_getComponent (cell);
+						/*
 						AccessibleComponent_getExtents (accessible_component,
 										&x, &y, &height, &width,
 										SPI_COORD_TYPE_SCREEN);
+						*/
+						AccessibleComponent_getPosition (accessible_component,
+										&x, &y,
+										SPI_COORD_TYPE_SCREEN);
+						AccessibleComponent_getSize (accessible_component,
+										 &height, &width);
 						AccessibleComponent_grabFocus (accessible_component);
 						flag = TRUE;
 						Accessible_unref (accessible_component);
@@ -958,13 +972,17 @@ right_click (Accessible *object, GSList *l)
 	} // for i
 	Accessible_unref (table);
 	if (flag) {
+		g_print ("x=%ld, y=%ld, width=%ld, height=%ld\n", x, y, width, height);
+		/*
 		if (SPI_generateMouseEvent (x + width / 2, y + height / 2, "b3c"))
 			return  (LDTP_ERROR_SUCCESS);
-		else
-			return 0;
+		*/
+		if (SPI_generateMouseEvent (x, y, "b3c"))
+			return  (LDTP_ERROR_SUCCESS);
 	}
-	else
-		return 0;
+	error =  (LDTP_ERROR_RIGHT_CLICK_FAILED);
+	log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
+	return error;
 }
 
 static LDTPErrorCode
@@ -1392,81 +1410,6 @@ get_status (Accessible *object, int row, int col)
 	return ret;
 }
 
-void 
-tree_table_cb (FILE *fp, const AccessibleEvent *event,
-	       char *window_name, char *window_type)
-{
-	long int i;
-	//long int *count;
-	char *tmp = NULL;
-	char *name = NULL;
-	char *role_name = NULL;
-	long int *selected_rows = NULL;
-	long total_rows = 0;
-	if (Accessible_getRole (event->source) == SPI_ROLE_TABLE_CELL) {
-		Accessible *object = NULL;
-		AccessibleTable *table_obj = NULL;
-		object = Accessible_getParent (event->source);
-		tmp = Accessible_getName (object); 
-		if (tmp) {
-			name = g_strdup (tmp);
-			SPI_freeString(tmp);
-		}
-		if ( name == NULL || strcmp (name, "") == 0 ) {
-			name = get_relation_name (object, NULL);
-		}
-	
-		table_obj = Accessible_getTable (object);
-		if (Accessible_isTable (table_obj) == FALSE )
-			g_print ("%%%%%%TABLE FAILED%%%%%%%%\n");
-		selected_rows = (long int *) malloc (AccessibleTable_getNRows (table_obj) *  sizeof (long int *));
-		total_rows = AccessibleTable_getSelectedRows(table_obj, &selected_rows);
-		role_name = Accessible_getRoleName (object);
-		for (i = 0; i < total_rows; i++) {
-			fprintf (fp, "<COMMAND><ACTION>SELECTROWINDEX</ACTION><WINDOW>%s</WINDOW><OBJECTTYPE>%s</OBJECTTYPE><CONTEXT>%s</CONTEXT><COMPONENT>%s</COMPONENT><ARGUMENTS><ARGUMENT>%ld</ARGUMENT></ARGUMENTS></COMMAND>\n", 
-				 window_type,
-				 role_name,
-				 window_name,
-				 name,
-				 *(selected_rows + i));
-		}
-		SPI_freeString (role_name);
-		g_free (selected_rows);
-		g_free (name);
-		Accessible_unref (object);
-		AccessibleTable_unref (table_obj);
-	}
-	else { //Control should come here when the call back is of SPI_ROLE_TREE_TABLE 
-		char *role = NULL;
-		AccessibleTable *obj = NULL;
-		role = Accessible_getRoleName(event->source);
-		tmp = Accessible_getName (event->source); 
-		if (tmp != NULL) {
-			name = g_strdup (tmp);
-			SPI_freeString(tmp);
-		}
-		if ( name == NULL || strcmp (name, "") == 0 ) {
-			name = get_relation_name (event->source, NULL);
-		}
-		obj = Accessible_getTable (event->source);
-		selected_rows = (long int *) malloc (AccessibleTable_getNRows (obj) *  sizeof (long int *));
-		total_rows = AccessibleTable_getSelectedRows (obj, &selected_rows);
-		for (i = 0; i < total_rows; i++) {
-			fprintf (fp,
-				 "<COMMAND><ACTION>SELECTROWINDEX</ACTION><WINDOW>%s</WINDOW><OBJECTTYPE>%s</OBJECTTYPE><CONTEXT>%s</CONTEXT><COMPONENT>%s</COMPONENT><ARGUMENTS><ARGUMENT>%ld</ARGUMENT></ARGUMENTS></COMMAND>\n", 
-				 window_type ,
-				 role,
-				 window_name ,
-				 name,
-				 *(selected_rows + i));
-		}
-		SPI_freeString (role) ;
-		g_free (selected_rows);
-		g_free (name);
-		AccessibleTable_unref (obj);
-	}
-}
-
 LDTPErrorCode
 tree_table_main (LDTPClientContext* cctxt, int command)
 {
@@ -1507,7 +1450,7 @@ tree_table_main (LDTPClientContext* cctxt, int command)
 		error = select_last_row (cctxt->gui_handle->handle, cctxt->log_fp);
 		break;
 	case LDTP_CMD_RIGHTCLICK:
-		error = right_click (cctxt->gui_handle->handle, cctxt->req->arg_list);
+		error = right_click (cctxt->gui_handle->handle, cctxt->req->arg_list, cctxt->log_fp);
 		break;
 	case LDTP_CMD_VERIFYTABLECELL:
 		error = verify_cell_value (cctxt);
